@@ -37,7 +37,7 @@ else:
     from urllib2 import urlopen #@UnresolvedImport @Reimport
 
 
-__version__ = "0.2.6"
+__version__ = "0.2.8"
 __author__ = "Chris Lucas"
 __contact__ = "chris@chrisjlucas.com"
 __license__ = "MIT"
@@ -61,14 +61,11 @@ class RTorrent:
         self._torrent_cache = []
 
         self._connect()
+        assert self._connected is True, "rTorrent connection failed"
         if self._connected:
             self.client_version_tuple = tuple([int(i) for i in \
                         self._p.system.client_version().split(".")])
 
-            self._build_method_dict()
-            self._method_list = self._method_dict[self.__class__.__name__]
-            rtorrent.rpc._build_rpc_methods(self, self._method_list)
-
             self.update()
             assert self._meets_version_requirement() is True, \
                 "Error: Minimum rTorrent version required is {0}".format(
@@ -85,21 +82,23 @@ class RTorrent:
             self._rpc_methods = self._p.system.listMethods()
             self._connected = True
         except xmlrpclib.ProtocolError as err:
-            sys.stderr.write("*** Exception caught: ProtocolError")
-            sys.stderr.write("URL: {0}".format(err.url))
-            sys.stderr.write("Error code: {0}".format(err.errcode))
-            sys.stderr.write("Error message: {0}".format(err.errmsg))
+            sys.stderr.write("*** Exception caught: ProtocolError\n")
+            sys.stderr.write("URL: {0}\n".format(err.url))
+            sys.stderr.write("Error code: {0}\n".format(err.errcode))
+            sys.stderr.write("Error message: {0}\n".format(err.errmsg))
         except xmlrpclib.ResponseError:
             sys.stderr.write("*** Exception caught: ResponseError")
 
-    def _build_method_dict(self):
-        self._method_dict = {}
-        for method_list in _all_methods_list:
-            for m in method_list:
-                if m.is_available(self):
-                    if m.class_name not in self._method_dict.keys():
-                        self._method_dict[m.class_name] = []
-                    self._method_dict[m.class_name].append(m)
+    ############### OBSOLETE ###################################################
+    # def _build_method_dict(self):
+    #    self._method_dict = {}
+    #    for method_list in _all_methods_list:
+    #        for m in method_list:
+    #            if m.is_available(self):
+    #                if m.class_name not in self._method_dict.keys():
+    #                    self._method_dict[m.class_name] = []
+    #                self._method_dict[m.class_name].append(m)
+    ############################################################################
 
     def _meets_version_requirement(self):
         """Check if rTorrent version is meets requirements"""
@@ -298,6 +297,10 @@ class RTorrent:
         """Alias for set_check_hash(False)"""
         self.set_check_hash(False)
 
+    def find_torrent(self, info_hash):
+        """Frontend for rtorrent.common.find_torrent"""
+        return(rtorrent.common.find_torrent(info_hash, self.get_torrents()))
+
     def poll(self):
         """ poll rTorrent to get latest torrent/peer/tracker/file information 
         
@@ -320,14 +323,12 @@ class RTorrent:
         @return: None
         """
         multicall = rtorrent.rpc.Multicall(self)
-        retriever_methods = [m for m in self._method_list \
+        retriever_methods = [m for m in methods \
                         if m.is_retriever() and m.is_available(self)]
         for method in retriever_methods:
             multicall.add(method)
 
-        result = multicall.call()
-        for m, r in zip(retriever_methods, result):
-            setattr(self, m.varname, rtorrent.rpc.process_result(m, r))
+        multicall.call()
 
 def _build_class_methods(class_obj):
     # multicall add class
@@ -347,156 +348,196 @@ def _build_class_methods(class_obj):
                         """
     setattr(class_obj, "multicall_add", caller)
 
+def __compare_rpc_methods(rt_new, rt_old):
+    from pprint import pprint
+    rt_new_methods = set(rt_new.get_rpc_methods())
+    rt_old_methods = set(rt_old.get_rpc_methods())
+    print("New Methods:")
+    pprint(rt_new_methods - rt_old_methods)
+    print("Methods not in new rTorrent:")
+    pprint(rt_old_methods - rt_new_methods)
+
+def __check_supported_methods(rt):
+    from pprint import pprint
+    supported_methods = set([m.rpc_call for m in
+                             methods + \
+                             rtorrent.file.methods + \
+                             rtorrent.torrent.methods + \
+                             rtorrent.tracker.methods + \
+                             rtorrent.peer.methods])
+    all_methods = set(rt.get_rpc_methods())
+
+    print("Methods NOT in supported methods")
+    pprint(all_methods - supported_methods)
+    print("Supported methods NOT in all methods")
+    pprint(supported_methods - all_methods)
+
 methods = [
     # RETRIEVERS
-    Method(RTorrent, 'get_xmlrpc_size_limit', 'get_xmlrpc_size_limit', None),
-    Method(RTorrent, 'get_proxy_address', 'get_proxy_address', None),
-    Method(RTorrent, 'get_split_suffix', 'get_split_suffix', None),
-    Method(RTorrent, 'get_up_limit', 'get_upload_rate', None),
-    Method(RTorrent, 'get_max_memory_usage', 'get_max_memory_usage', None),
-    Method(RTorrent, 'get_max_open_files', 'get_max_open_files', None),
-    Method(RTorrent, 'get_min_peers_seed', 'get_min_peers_seed', None),
-    Method(RTorrent, 'get_use_udp_trackers', 'get_use_udp_trackers', None),
-    Method(RTorrent, 'get_preload_min_size', 'get_preload_min_size', None),
-    Method(RTorrent, 'get_max_uploads', 'get_max_uploads', None),
-    Method(RTorrent, 'get_max_peers', 'get_max_peers', None),
-    Method(RTorrent, 'get_timeout_sync', 'get_timeout_sync', None),
-    Method(RTorrent, 'get_receive_buffer_size', 'get_receive_buffer_size', None),
-    Method(RTorrent, 'get_split_file_size', 'get_split_file_size', None),
-    Method(RTorrent, 'get_dht_throttle', 'get_dht_throttle', None),
-    Method(RTorrent, 'get_max_peers_seed', 'get_max_peers_seed', None),
-    Method(RTorrent, 'get_min_peers', 'get_min_peers', None),
-    Method(RTorrent, 'get_tracker_numwant', 'get_tracker_numwant', None),
-    Method(RTorrent, 'get_max_open_sockets', 'get_max_open_sockets', None),
-    Method(RTorrent, 'get_session', 'get_session', None),
-    Method(RTorrent, 'get_ip', 'get_ip', None),
-    Method(RTorrent, 'get_scgi_dont_route', 'get_scgi_dont_route', None),
-    Method(RTorrent, 'get_hash_read_ahead', 'get_hash_read_ahead', None),
-    Method(RTorrent, 'get_http_cacert', 'get_http_cacert', None),
-    Method(RTorrent, 'get_dht_port', 'get_dht_port', None),
-    Method(RTorrent, 'get_handshake_log', 'get_handshake_log', None),
-    Method(RTorrent, 'get_preload_type', 'get_preload_type', None),
-    Method(RTorrent, 'get_max_open_http', 'get_max_open_http', None),
-    Method(RTorrent, 'get_http_capath', 'get_http_capath', None),
-    Method(RTorrent, 'get_max_downloads_global', 'get_max_downloads_global', None),
-    Method(RTorrent, 'get_name', 'get_name', None),
-    Method(RTorrent, 'get_session_on_completion', 'get_session_on_completion', None),
-    Method(RTorrent, 'get_down_limit', 'get_download_rate', None),
-    Method(RTorrent, 'get_down_total', 'get_down_total', None),
-    Method(RTorrent, 'get_up_rate', 'get_up_rate', None),
-    Method(RTorrent, 'get_hash_max_tries', 'get_hash_max_tries', None),
-    Method(RTorrent, 'get_peer_exchange', 'get_peer_exchange', None),
-    Method(RTorrent, 'get_down_rate', 'get_down_rate', None),
-    Method(RTorrent, 'get_connection_seed', 'get_connection_seed', None),
-    Method(RTorrent, 'get_http_proxy', 'get_http_proxy', None),
-    Method(RTorrent, 'get_stats_preloaded', 'get_stats_preloaded', None),
-    Method(RTorrent, 'get_timeout_safe_sync', 'get_timeout_safe_sync', None),
-    Method(RTorrent, 'get_hash_interval', 'get_hash_interval', None),
-    Method(RTorrent, 'get_port_random', 'get_port_random', None),
-    Method(RTorrent, 'get_directory', 'get_directory', None),
-    Method(RTorrent, 'get_port_open', 'get_port_open', None),
-    Method(RTorrent, 'get_max_file_size', 'get_max_file_size', None),
-    Method(RTorrent, 'get_stats_not_preloaded', 'get_stats_not_preloaded', None),
-    Method(RTorrent, 'get_memory_usage', 'get_memory_usage', None),
-    Method(RTorrent, 'get_connection_leech', 'get_connection_leech', None),
-    Method(RTorrent, 'get_check_hash', 'get_check_hash', None, boolean=True),
-    Method(RTorrent, 'get_session_lock', 'get_session_lock', None),
-    Method(RTorrent, 'get_preload_required_rate', 'get_preload_required_rate', None),
-    Method(RTorrent, 'get_max_uploads_global', 'get_max_uploads_global', None),
-    Method(RTorrent, 'get_send_buffer_size', 'get_send_buffer_size', None),
-    Method(RTorrent, 'get_port_range', 'get_port_range', None),
-    Method(RTorrent, 'get_max_downloads_div', 'get_max_downloads_div', None),
-    Method(RTorrent, 'get_max_uploads_div', 'get_max_uploads_div', None),
-    Method(RTorrent, 'get_safe_sync', 'get_safe_sync', None),
-   #Method(RTorrent, 'get_log.tracker', 'get_log.tracker', None),
-    Method(RTorrent, 'get_bind', 'get_bind', None),
-    Method(RTorrent, 'get_up_total', 'get_up_total', None),
-    Method(RTorrent, 'get_client_version', 'system.client_version', None),
-    Method(RTorrent, 'get_library_version', 'system.library_version', None),
+    Method(RTorrent, 'get_xmlrpc_size_limit', 'get_xmlrpc_size_limit'),
+    Method(RTorrent, 'get_proxy_address', 'get_proxy_address'),
+    Method(RTorrent, 'get_split_suffix', 'get_split_suffix'),
+    Method(RTorrent, 'get_up_limit', 'get_upload_rate'),
+    Method(RTorrent, 'get_max_memory_usage', 'get_max_memory_usage'),
+    Method(RTorrent, 'get_max_open_files', 'get_max_open_files'),
+    Method(RTorrent, 'get_min_peers_seed', 'get_min_peers_seed'),
+    Method(RTorrent, 'get_use_udp_trackers', 'get_use_udp_trackers'),
+    Method(RTorrent, 'get_preload_min_size', 'get_preload_min_size'),
+    Method(RTorrent, 'get_max_uploads', 'get_max_uploads'),
+    Method(RTorrent, 'get_max_peers', 'get_max_peers'),
+    Method(RTorrent, 'get_timeout_sync', 'get_timeout_sync'),
+    Method(RTorrent, 'get_receive_buffer_size', 'get_receive_buffer_size'),
+    Method(RTorrent, 'get_split_file_size', 'get_split_file_size'),
+    Method(RTorrent, 'get_dht_throttle', 'get_dht_throttle'),
+    Method(RTorrent, 'get_max_peers_seed', 'get_max_peers_seed'),
+    Method(RTorrent, 'get_min_peers', 'get_min_peers'),
+    Method(RTorrent, 'get_tracker_numwant', 'get_tracker_numwant'),
+    Method(RTorrent, 'get_max_open_sockets', 'get_max_open_sockets'),
+    Method(RTorrent, 'get_session', 'get_session'),
+    Method(RTorrent, 'get_ip', 'get_ip'),
+    Method(RTorrent, 'get_scgi_dont_route', 'get_scgi_dont_route'),
+    Method(RTorrent, 'get_hash_read_ahead', 'get_hash_read_ahead'),
+    Method(RTorrent, 'get_http_cacert', 'get_http_cacert'),
+    Method(RTorrent, 'get_dht_port', 'get_dht_port'),
+    Method(RTorrent, 'get_handshake_log', 'get_handshake_log'),
+    Method(RTorrent, 'get_preload_type', 'get_preload_type'),
+    Method(RTorrent, 'get_max_open_http', 'get_max_open_http'),
+    Method(RTorrent, 'get_http_capath', 'get_http_capath'),
+    Method(RTorrent, 'get_max_downloads_global', 'get_max_downloads_global'),
+    Method(RTorrent, 'get_name', 'get_name'),
+    Method(RTorrent, 'get_session_on_completion', 'get_session_on_completion'),
+    Method(RTorrent, 'get_down_limit', 'get_download_rate'),
+    Method(RTorrent, 'get_down_total', 'get_down_total'),
+    Method(RTorrent, 'get_up_rate', 'get_up_rate'),
+    Method(RTorrent, 'get_hash_max_tries', 'get_hash_max_tries'),
+    Method(RTorrent, 'get_peer_exchange', 'get_peer_exchange'),
+    Method(RTorrent, 'get_down_rate', 'get_down_rate'),
+    Method(RTorrent, 'get_connection_seed', 'get_connection_seed'),
+    Method(RTorrent, 'get_http_proxy', 'get_http_proxy'),
+    Method(RTorrent, 'get_stats_preloaded', 'get_stats_preloaded'),
+    Method(RTorrent, 'get_timeout_safe_sync', 'get_timeout_safe_sync'),
+    Method(RTorrent, 'get_hash_interval', 'get_hash_interval'),
+    Method(RTorrent, 'get_port_random', 'get_port_random'),
+    Method(RTorrent, 'get_directory', 'get_directory'),
+    Method(RTorrent, 'get_port_open', 'get_port_open'),
+    Method(RTorrent, 'get_max_file_size', 'get_max_file_size'),
+    Method(RTorrent, 'get_stats_not_preloaded', 'get_stats_not_preloaded'),
+    Method(RTorrent, 'get_memory_usage', 'get_memory_usage'),
+    Method(RTorrent, 'get_connection_leech', 'get_connection_leech'),
+    Method(RTorrent, 'get_check_hash', 'get_check_hash',
+           boolean=True,
+           ),
+    Method(RTorrent, 'get_session_lock', 'get_session_lock'),
+    Method(RTorrent, 'get_preload_required_rate', 'get_preload_required_rate'),
+    Method(RTorrent, 'get_max_uploads_global', 'get_max_uploads_global'),
+    Method(RTorrent, 'get_send_buffer_size', 'get_send_buffer_size'),
+    Method(RTorrent, 'get_port_range', 'get_port_range'),
+    Method(RTorrent, 'get_max_downloads_div', 'get_max_downloads_div'),
+    Method(RTorrent, 'get_max_uploads_div', 'get_max_uploads_div'),
+    Method(RTorrent, 'get_safe_sync', 'get_safe_sync'),
+    Method(RTorrent, 'get_bind', 'get_bind'),
+    Method(RTorrent, 'get_up_total', 'get_up_total'),
+    Method(RTorrent, 'get_client_version', 'system.client_version'),
+    Method(RTorrent, 'get_library_version', 'system.library_version'),
+    Method(RTorrent, 'get_api_version', 'system.api_version',
+           min_version=(0, 9, 1)
+           ),
+    Method(RTorrent, "get_system_time", "system.time",
+           docstring="""Get the current time of the system rTorrent is running on
+           
+           @return: time (posix)
+           @rtype: int""",
+           ),
 
     # MODIFIERS
-    Method(RTorrent, 'set_http_proxy', 'set_http_proxy', None),
-    Method(RTorrent, 'set_max_memory_usage', 'set_max_memory_usage', None),
-    Method(RTorrent, 'set_max_file_size', 'set_max_file_size', None),
+    Method(RTorrent, 'set_http_proxy', 'set_http_proxy'),
+    Method(RTorrent, 'set_max_memory_usage', 'set_max_memory_usage'),
+    Method(RTorrent, 'set_max_file_size', 'set_max_file_size'),
     Method(RTorrent, 'set_bind', 'set_bind',
-           """Set address bind
+           docstring="""Set address bind
            
            @param arg: ip address
            @type arg: str
-           """),
+           """,
+           ),
     Method(RTorrent, 'set_up_limit', 'set_upload_rate',
-           """Set global upload limit (in bytes)
+           docstring="""Set global upload limit (in bytes)
            
            @param arg: speed limit
            @type arg: int
-           """),
-    Method(RTorrent, 'set_port_random', 'set_port_random', None),
-    Method(RTorrent, 'set_connection_leech', 'set_connection_leech', None),
-    Method(RTorrent, 'set_tracker_numwant', 'set_tracker_numwant', None),
-    Method(RTorrent, 'set_max_peers', 'set_max_peers', None),
-    Method(RTorrent, 'set_min_peers', 'set_min_peers', None),
-    Method(RTorrent, 'set_max_uploads_div', 'set_max_uploads_div', None),
-    Method(RTorrent, 'set_max_open_files', 'set_max_open_files', None),
-    Method(RTorrent, 'set_max_downloads_global', 'set_max_downloads_global', None),
-    Method(RTorrent, 'set_session_lock', 'set_session_lock', None),
-    Method(RTorrent, 'set_session', 'set_session', None),
-    Method(RTorrent, 'set_split_suffix', 'set_split_suffix', None),
-    Method(RTorrent, 'set_hash_interval', 'set_hash_interval', None),
-    Method(RTorrent, 'set_handshake_log', 'set_handshake_log', None),
-    Method(RTorrent, 'set_port_range', 'set_port_range', None),
-    Method(RTorrent, 'set_min_peers_seed', 'set_min_peers_seed', None),
-    Method(RTorrent, 'set_scgi_dont_route', 'set_scgi_dont_route', None),
-    Method(RTorrent, 'set_preload_min_size', 'set_preload_min_size', None),
-    Method(RTorrent, 'set_log.tracker', 'set_log.tracker', None),
-    Method(RTorrent, 'set_max_uploads_global', 'set_max_uploads_global', None),
+           """,
+           ),
+    Method(RTorrent, 'set_port_random', 'set_port_random'),
+    Method(RTorrent, 'set_connection_leech', 'set_connection_leech'),
+    Method(RTorrent, 'set_tracker_numwant', 'set_tracker_numwant'),
+    Method(RTorrent, 'set_max_peers', 'set_max_peers'),
+    Method(RTorrent, 'set_min_peers', 'set_min_peers'),
+    Method(RTorrent, 'set_max_uploads_div', 'set_max_uploads_div'),
+    Method(RTorrent, 'set_max_open_files', 'set_max_open_files'),
+    Method(RTorrent, 'set_max_downloads_global', 'set_max_downloads_global'),
+    Method(RTorrent, 'set_session_lock', 'set_session_lock'),
+    Method(RTorrent, 'set_session', 'set_session'),
+    Method(RTorrent, 'set_split_suffix', 'set_split_suffix'),
+    Method(RTorrent, 'set_hash_interval', 'set_hash_interval'),
+    Method(RTorrent, 'set_handshake_log', 'set_handshake_log'),
+    Method(RTorrent, 'set_port_range', 'set_port_range'),
+    Method(RTorrent, 'set_min_peers_seed', 'set_min_peers_seed'),
+    Method(RTorrent, 'set_scgi_dont_route', 'set_scgi_dont_route'),
+    Method(RTorrent, 'set_preload_min_size', 'set_preload_min_size'),
+    Method(RTorrent, 'set_log.tracker', 'set_log.tracker'),
+    Method(RTorrent, 'set_max_uploads_global', 'set_max_uploads_global'),
     Method(RTorrent, 'set_down_limit', 'set_download_rate',
-           """Set global download limit (in bytes)
+           docstring="""Set global download limit (in bytes)
            
            @param arg: speed limit
            @type arg: int
-           """),
-    Method(RTorrent, 'set_preload_required_rate', 'set_preload_required_rate', None),
-    Method(RTorrent, 'set_hash_read_ahead', 'set_hash_read_ahead', None),
-    Method(RTorrent, 'set_max_peers_seed', 'set_max_peers_seed', None),
-    Method(RTorrent, 'set_max_uploads', 'set_max_uploads', None),
-    Method(RTorrent, 'set_session_on_completion', 'set_session_on_completion', None),
-    Method(RTorrent, 'set_max_open_http', 'set_max_open_http', None),
-    Method(RTorrent, 'set_directory', 'set_directory', None),
-    Method(RTorrent, 'set_http_cacert', 'set_http_cacert', None),
-    Method(RTorrent, 'set_dht_throttle', 'set_dht_throttle', None),
-    Method(RTorrent, 'set_hash_max_tries', 'set_hash_max_tries', None),
-    Method(RTorrent, 'set_proxy_address', 'set_proxy_address', None),
-    Method(RTorrent, 'set_split_file_size', 'set_split_file_size', None),
-    Method(RTorrent, 'set_receive_buffer_size', 'set_receive_buffer_size', None),
-    Method(RTorrent, 'set_use_udp_trackers', 'set_use_udp_trackers', None),
-    Method(RTorrent, 'set_connection_seed', 'set_connection_seed', None),
-    Method(RTorrent, 'set_xmlrpc_size_limit', 'set_xmlrpc_size_limit', None),
-    Method(RTorrent, 'set_xmlrpc_dialect', 'set_xmlrpc_dialect', None),
-    Method(RTorrent, 'set_safe_sync', 'set_safe_sync', None),
-    Method(RTorrent, 'set_http_capath', 'set_http_capath', None),
-    Method(RTorrent, 'set_send_buffer_size', 'set_send_buffer_size', None),
-    Method(RTorrent, 'set_max_downloads_div', 'set_max_downloads_div', None),
-    Method(RTorrent, 'set_name', 'set_name', None),
-    Method(RTorrent, 'set_port_open', 'set_port_open', None),
-    Method(RTorrent, 'set_timeout_sync', 'set_timeout_sync', None),
-    Method(RTorrent, 'set_peer_exchange', 'set_peer_exchange', None),
+           """,
+           ),
+    Method(RTorrent, 'set_preload_required_rate', 'set_preload_required_rate'),
+    Method(RTorrent, 'set_hash_read_ahead', 'set_hash_read_ahead'),
+    Method(RTorrent, 'set_max_peers_seed', 'set_max_peers_seed'),
+    Method(RTorrent, 'set_max_uploads', 'set_max_uploads'),
+    Method(RTorrent, 'set_session_on_completion', 'set_session_on_completion'),
+    Method(RTorrent, 'set_max_open_http', 'set_max_open_http'),
+    Method(RTorrent, 'set_directory', 'set_directory'),
+    Method(RTorrent, 'set_http_cacert', 'set_http_cacert'),
+    Method(RTorrent, 'set_dht_throttle', 'set_dht_throttle'),
+    Method(RTorrent, 'set_hash_max_tries', 'set_hash_max_tries'),
+    Method(RTorrent, 'set_proxy_address', 'set_proxy_address'),
+    Method(RTorrent, 'set_split_file_size', 'set_split_file_size'),
+    Method(RTorrent, 'set_receive_buffer_size', 'set_receive_buffer_size'),
+    Method(RTorrent, 'set_use_udp_trackers', 'set_use_udp_trackers'),
+    Method(RTorrent, 'set_connection_seed', 'set_connection_seed'),
+    Method(RTorrent, 'set_xmlrpc_size_limit', 'set_xmlrpc_size_limit'),
+    Method(RTorrent, 'set_xmlrpc_dialect', 'set_xmlrpc_dialect'),
+    Method(RTorrent, 'set_safe_sync', 'set_safe_sync'),
+    Method(RTorrent, 'set_http_capath', 'set_http_capath'),
+    Method(RTorrent, 'set_send_buffer_size', 'set_send_buffer_size'),
+    Method(RTorrent, 'set_max_downloads_div', 'set_max_downloads_div'),
+    Method(RTorrent, 'set_name', 'set_name'),
+    Method(RTorrent, 'set_port_open', 'set_port_open'),
+    Method(RTorrent, 'set_timeout_sync', 'set_timeout_sync'),
+    Method(RTorrent, 'set_peer_exchange', 'set_peer_exchange'),
     Method(RTorrent, 'set_ip', 'set_ip',
-           """Set IP
+           docstring="""Set IP
            
            @param arg: ip address
            @type arg: str
-           """),
-    Method(RTorrent, 'set_timeout_safe_sync', 'set_timeout_safe_sync', None),
-    Method(RTorrent, 'set_preload_type', 'set_preload_type', None),
+           """,
+           ),
+    Method(RTorrent, 'set_timeout_safe_sync', 'set_timeout_safe_sync'),
+    Method(RTorrent, 'set_preload_type', 'set_preload_type'),
     Method(RTorrent, 'set_check_hash', 'set_check_hash',
-           """Enable/Disable hash checking on finished torrents
+           docstring="""Enable/Disable hash checking on finished torrents
         
             @param arg: True to enable, False to disable
             @type arg: bool
-            """, boolean=True),
+            """,
+            boolean=True,
+            ),
     # just testing
-    Method(RTorrent, 'fake_method', 'get_fake_method', None),
-    Method(RTorrent, 'fake_method_dos', 'get_fake_method_dos', None,
+    Method(RTorrent, 'fake_method', 'get_fake_method'),
+    Method(RTorrent, 'fake_method_dos', 'get_fake_method_dos',
            min_version=(9, 9, 9)),
 ]
 
@@ -507,8 +548,12 @@ _all_methods_list = [methods,
                     rtorrent.peer.methods,
 ]
 
-for c in [rtorrent.file.File,
-          rtorrent.torrent.Torrent,
-          rtorrent.tracker.Tracker,
-          rtorrent.peer.Peer]:
+class_methods_pair = {
+    rtorrent.file.File : rtorrent.file.methods,
+    rtorrent.torrent.Torrent : rtorrent.torrent.methods,
+    rtorrent.tracker.Tracker : rtorrent.tracker.methods,
+    rtorrent.peer.Peer : rtorrent.peer.methods,
+}
+for c in class_methods_pair.keys():
+    rtorrent.rpc._build_rpc_methods(c, class_methods_pair[c])
     _build_class_methods(c)
